@@ -7,7 +7,7 @@ from typing import Optional, Text, List, Any
 from pykechain import Client
 from pykechain.enums import PropertyType, Multiplicity, Category
 from pykechain.exceptions import IllegalArgumentError, NotFoundError, MultipleFoundError
-from pykechain.models import Part, AnyProperty, Property
+from pykechain.models import Part, AnyProperty, Property, PropertyValueFilter
 from pykechain.utils import temp_chdir
 
 # global variable
@@ -16,7 +16,6 @@ __edited_one_many: list = list()
 __references = dict()
 __attachments = list()
 
-
 _InstanceCopy = namedtuple(
     "InstanceCopyAttributes",
     field_names=[
@@ -124,14 +123,15 @@ def map_property_instances(original_part: Part, new_part: Part) -> None:
     # Do the same for each Property of original part instance, using the 'model' id and the get_mapping_dictionary
     for prop_original in original_part.properties:
         mapping[prop_original.id] = [
-            prop_new for prop_new in new_part.properties if mapping[prop_original.model_id].id == prop_new.model_id][0]
+            prop_new for prop_new in new_part.properties if
+            mapping[prop_original.model_id].id == prop_new.model_id][0]
 
 
 def relocate_model(
-        part: Part,
-        target_parent: Part,
-        name: Optional[Text] = None,
-        include_children: Optional[bool] = True
+    part: Part,
+    target_parent: Part,
+    name: Optional[Text] = None,
+    include_children: Optional[bool] = True
 ) -> Part:
     """
     Move the `Part` model under a target parent `Part` model.
@@ -155,8 +155,9 @@ def relocate_model(
     )
 
     if target_parent.id in get_illegal_targets(part, include={part.id}):
-        raise IllegalArgumentError("Cannot relocate part `{}` under target parent `{}`, because the target is part of "
-                                   "its descendants".format(part.name, target_parent.name))
+        raise IllegalArgumentError(
+            "Cannot relocate part `{}` under target parent `{}`, because the target is part of "
+            "its descendants".format(part.name, target_parent.name))
 
     if include_children:
         part.populate_descendants()
@@ -188,10 +189,10 @@ def relocate_model(
 
 
 def move_part_model(
-        part: Part,
-        target_parent: Part,
-        name: Text,
-        include_children: bool,
+    part: Part,
+    target_parent: Part,
+    name: Text,
+    include_children: bool,
 ) -> Part:
     """
     Copy the `Part` model under a target parent `Part` model, recursively.
@@ -221,10 +222,10 @@ def move_part_model(
 
 
 def _copy_part_model(
-        part: Part,
-        target_parent: Part,
-        name: Text,
-        include_children: bool,
+    part: Part,
+    target_parent: Part,
+    name: Text,
+    include_children: bool,
 ) -> Part:
     """
     Copy the `Part` model under a target parent `Part` model, including its descendants recursively.
@@ -285,10 +286,10 @@ def _copy_part_model(
 
 
 def relocate_instance(
-        part: Part,
-        target_parent: Part,
-        name: Optional[Text] = None,
-        include_children: Optional[bool] = True,
+    part: Part,
+    target_parent: Part,
+    name: Optional[Text] = None,
+    include_children: Optional[bool] = True,
 ) -> Part:
     """
     Move the `Part` instance under a target parent `Part` instance.
@@ -354,11 +355,11 @@ def relocate_instance(
 
 
 def move_part_instance(
-        part_instance: Part,
-        target_parent: Part,
-        part_model: Part,
-        name: Optional[Text] = None,
-        include_children: Optional[bool] = True
+    part_instance: Part,
+    target_parent: Part,
+    part_model: Part,
+    name: Optional[Text] = None,
+    include_children: Optional[bool] = True
 ) -> Part:
     """
     Copy the `Part` instance to target parent and updates the properties based on the original part instance.
@@ -427,9 +428,9 @@ def move_part_instance(
 
 
 def update_part_with_properties(
-        part_instance: Part,
-        moved_instance: Part,
-        name: Optional[Text] = None,
+    part_instance: Part,
+    moved_instance: Part,
+    name: Optional[Text] = None,
 ) -> Part:
     """
     Update the properties of the `moved_instance` based on the original `part_instance`.
@@ -482,17 +483,18 @@ def update_part_with_properties(
             properties_id_dict[moved_prop_instance.id] = prop_instance.value
 
     # Update the name and property values in one go.
-    moved_instance.update(name=str(name), update_dict=properties_id_dict, bulk=True, suppress_kevents=True)
+    moved_instance.update(name=str(name), update_dict=properties_id_dict, bulk=True,
+                          suppress_kevents=True)
 
     return moved_instance
 
 
 def _copy_part(
-        part: Part,
-        target_parent: Part,
-        name: Optional[Text] = None,
-        include_children: Optional[bool] = True,
-        include_instances: Optional[bool] = True,
+    part: Part,
+    target_parent: Part,
+    name: Optional[Text] = None,
+    include_children: Optional[bool] = True,
+    include_instances: Optional[bool] = True,
 ) -> Part:
     """
     Copy `part` below `target_parent`, optionally including all child Parts.
@@ -539,11 +541,13 @@ def _copy_part(
             except NotFoundError:
                 raise IllegalArgumentError(
                     "Cannot copy part model `{}` including instances, since the target_parent model `{}` has no "
-                    "instance to act as parent for the instances.".format(model, target_parent_model))
+                    "instance to act as parent for the instances.".format(model,
+                                                                          target_parent_model))
             except MultipleFoundError:
                 raise IllegalArgumentError(
                     "Cannot copy part model `{}` including instances, since the target_parent model `{}` has multiple "
-                    "instances, making the parent for the instances ambiguous.".format(model, target_parent_model)
+                    "instances, making the parent for the instances ambiguous.".format(model,
+                                                                                       target_parent_model)
                 )
 
             instances = [_InstanceCopy(
@@ -558,8 +562,9 @@ def _copy_part(
     # Verify if the target_parent is not below the part
     model.populate_descendants()
     if target_parent_model.id in get_illegal_targets(model, include={model.id}):
-        raise IllegalArgumentError("Cannot relocate part `{}` under target parent `{}`, because the target is part of "
-                                   "its descendants".format(model.name, target_parent.name))
+        raise IllegalArgumentError(
+            "Cannot relocate part `{}` under target parent `{}`, because the target is part of "
+            "its descendants".format(model.name, target_parent.name))
 
     copied_model = _copy_part_model(
         part=model,
@@ -595,9 +600,9 @@ def _copy_part(
 
 
 def _copy_instances_recursive(
-        client: Client,
-        instances: List[_InstanceCopy],
-        include_children: bool,
+    client: Client,
+    instances: List[_InstanceCopy],
+    include_children: bool,
 ) -> List[Part]:
     """
     Create new Part instances in bulk, recursively.
@@ -678,7 +683,8 @@ def _copy_instances_recursive(
             retrieve_instances=True,
         )
         for index, new_instance, i in \
-                zip(created_instances_indices, created_instances, original_instances):  # type: int, Part, _InstanceCopy
+            zip(created_instances_indices, created_instances,
+                original_instances):  # type: int, Part, _InstanceCopy
             new_instances[index] = new_instance
             map_property_instances(original_part=i.instance_original, new_part=new_instance)
 
@@ -719,7 +725,52 @@ def _update_references() -> None:
 
         # Try to map to a new Part, default to the existing reference ID itself.
         references_new = [mapping.get(r, r) for r in references_original]
-        prop_new.value = references_new
+        if prop_new.type == PropertyType.REFERENCES_VALUE and references_new:
+
+            if len(references_original) == 0:
+                continue
+
+            # Update the scope_id to match the new referenced part model
+            # For parts copied in the same subtree
+            if isinstance(references_new[0], Part):
+                prop_new_options = {"scope_id": references_new[0].scope_id}
+                prop_value = [ref.id for ref in references_new]
+            # For parts left in the project from which they are copied from
+            else:
+                prop_value = list()
+                for part_id in references_new:
+                    referenced_part = prop_new._client.part(id=part_id, category=prop_new.category)
+                    prop_value.append(referenced_part.id)
+                prop_new_options = {"scope_id": prop_new._client.part(
+                    id=references_new[0], category=prop_new.category).scope_id}
+
+            # Make sure the excluded property models ids are mapped on the new referenced part
+            # model
+            original_excluded_propmodel_ids = prop_original.get_excluded_propmodel_ids()
+            if original_excluded_propmodel_ids:
+                prop_new_options.update({
+                    "propmodels_excl": [mapping.get(r).id for r in
+                                        original_excluded_propmodel_ids if r in mapping]
+                })
+
+            # Remap the prefilters on new referenced part model.
+            original_prefilters = prop_original.get_prefilters()
+            if original_prefilters:
+                new_prefilters = [PropertyValueFilter(
+                    value=ovf.value,
+                    filter_type=ovf.type,
+                    property_model=mapping.get(ovf.id, ovf.id),
+                ) for ovf in original_prefilters]
+                prop_new_options.update(PropertyValueFilter.write_options(filters=new_prefilters))
+
+            # Update the value and options (prefilters, excluded prop models and scope_id) in bulk
+            if prop_new.category == Category.MODEL:
+                prop_new.edit(value=prop_value,
+                              options=prop_new_options)
+            else:
+                prop_new.value = prop_value
+        else:
+            prop_new.value = references_new
 
     get_references(clean=True)
 
