@@ -1,8 +1,9 @@
 from pykechain.enums import (
+    FontAwesomeMode,
+    GeoCoordinateConfig,
+    LinkTargets,
     PropertyRepresentation,
     SelectListRepresentations,
-    LinkTargets,
-    FontAwesomeMode, GeoCoordinateConfig,
 )
 from pykechain.exceptions import IllegalArgumentError
 from pykechain.models.input_checks import check_type
@@ -176,7 +177,7 @@ class CustomIconRepresentation(BaseRepresentation):
 
 
 class GeoCoordinateRepresentation(BaseRepresentation):
-    """Representation for HTML link reference properties.
+    """Representation for Geocoordinate properties.
 
     It should look like this in the value_options
     #         "representations": [
@@ -188,7 +189,6 @@ class GeoCoordinateRepresentation(BaseRepresentation):
     #             }
     #         ]
     #     },
-
     """
 
     rtype = PropertyRepresentation.GEOCOORDINATE
@@ -208,3 +208,20 @@ class GeoCoordinateRepresentation(BaseRepresentation):
                     self.__class__.__name__, value, GeoCoordinateConfig.values()
                 )
             )
+
+
+class UsePropertyNameRepresentation(BaseRepresentation):
+    """Representation for the use of Property Names in a reference property."""
+
+    rtype = PropertyRepresentation.USE_PROPERTY_NAME
+    _config_value_key = PropertyRepresentation.USE_PROPERTY_NAME
+
+    def validate_representation(self, value: bool) -> None:
+        """
+        Validate whether the representation value can be set.
+
+        :param value: representation value to set.
+        :type value: a boolean
+        :return: None
+        """
+        check_type(value, bool, self._config_value_key)
